@@ -1,7 +1,8 @@
 import grequests
 
 def fetch(url):
-    return grequests.get('http://www.linkedin.com/countserv/count/share', params={'url': url})
+    return grequests.get('http://www.linkedin.com/countserv/count/share', 
+        params={'url': url, 'format': 'json'})
 
 def parse(response):
     if response.status_code != 200:
